==> metlo-0.1.2.tgz: package/src/rust_binds.ts <==
import { Logger } from "./utils/logger"

let startup, parse_trace, block_trace, imports
let enable = true
let canStart = false
if (process.platform === "linux") {
  imports = require("@metlo/metlo-node-agent-bindings-linux")
} else if (process.platform === "win32") {
  imports = require("@metlo/metlo-node-agent-bindings-windows")
} else if (process.platform === "darwin") {
  if (process.arch === "x64") {
    imports = require("@metlo/metlo-node-agent-bindings-mac")
  } else if (process.arch === "arm64") {
    imports = require("@metlo/metlo-node-agent-bindings-mac-arm64")
  } else {
    Logger().log(
      "warn",
      `Metlo will not be enabled due to usage on unsupported architecture ${process.arch} on darwin.\nCurrently, metlo supports x86 and arm64 systems.`,
    )
    enable = false
  }
} else {
  Logger().log(
    "warn",
    `Metlo will not be enabled due to usage on unsupported platform ${process.platform}.\nCurrently, metlo supports linux, windows and mac systems.`,
  )
  enable = false
}

startup = imports.startup
parse_trace = imports.parse_trace
block_trace = imports.block_trace

export const startMetlo = async (
  metloHost,
  metloApiKey,
  backendPort,
  collectorPort,
  encryptionKey,
  logLevel,
) => {
  try {
    if (enable) {
      // First two params are required. The rest are optional.
      const params = []
      params.push(metloHost)
      params.push(metloApiKey)
      if (collectorPort) {
        params.push(collectorPort)
      } else {
        params.push(null)
      }
      if (backendPort) {
        params.push(backendPort)
      } else {
        params.push(null)
      }
      if (encryptionKey) {
        params.push(encryptionKey)
      } else {
        params.push(null)
      }
      if (logLevel) {
        if (["info", "debug", "trace", "error", "warn"].includes(logLevel)) {
          params.push(logLevel)
        } else {
          params.push("info")
        }
      } else {
        params.push("info")
      }

      return new Promise((resolve, reject) => {
        startup.apply({}, params).then((response: boolean) => {
          if (response) {
            canStart = true
            resolve(true)
          } else {
            reject(false)
          }
        })
      })
    }
    return new Promise(() => false)
  } catch (err) {
    enable = false
    Logger().log("debug", err)
    return new Promise(() => false)
  }
}

export const sendMetloTrace = (trace, user) => {
  try {
    if (canStart) {
      parse_trace(trace, user)
    } else {
      Logger().log(
        "debug",
        "Metlo did not start succesfully. Please check logs for more info.",
      )
    }
  } catch (err) {
    Logger().log("debug", err)
  }
}

export const shouldBlock = (requestTrace, requestMetadata) => {
  try {
    if (canStart) {
      return block_trace(requestTrace, requestMetadata)
    } else {
      Logger().log(
        "debug",
        "Metlo did not start succesfully. Please check logs for more info.",
      )
      return false
    }
  } catch (err) {
    Logger().log("debug", err)
    return false
  }
}

==> metlo-0.1.3.tgz: package/src/rust_binds.ts <==
import { Logger } from "./utils/logger"

let startup, parse_trace, block_trace, imports
let enable = true
let canStart = false
let silenceNotStartWarnings = false
if (process.platform === "linux") {
  imports = require("@metlo/metlo-node-agent-bindings-linux")
} else if (process.platform === "win32") {
  imports = require("@metlo/metlo-node-agent-bindings-windows")
} else if (process.platform === "darwin") {
  if (process.arch === "x64") {
    imports = require("@metlo/metlo-node-agent-bindings-mac")
  } else if (process.arch === "arm64") {
    imports = require("@metlo/metlo-node-agent-bindings-mac-arm64")
  } else {
    Logger().log(
      "warn",
      `Metlo will not be enabled due to usage on unsupported architecture ${process.arch} on darwin.\nCurrently, metlo supports x86 and arm64 systems.`,
    )
    enable = false
  }
} else {
  Logger().log(
    "warn",
    `Metlo will not be enabled due to usage on unsupported platform ${process.platform}.\nCurrently, metlo supports linux, windows and mac systems.`,
  )
  enable = false
}

startup = imports.startup
parse_trace = imports.parse_trace
block_trace = imports.block_trace

export const startMetlo = async (
  metloHost,
  metloApiKey,
  backendPort,
  collectorPort,
  encryptionKey,
  logLevel,
) => {
  try {
    if (enable) {
      // First two params are required. The rest are optional.
      const params = []
      params.push(metloHost)
      params.push(metloApiKey)
      if (collectorPort) {
        params.push(collectorPort)
      } else {
        params.push(null)
      }
      if (backendPort) {
        params.push(backendPort)
      } else {
        params.push(null)
      }
      if (encryptionKey) {
        params.push(encryptionKey)
      } else {
        params.push(null)
      }
      if (logLevel) {
        if (["info", "debug", "trace", "error", "warn"].includes(logLevel)) {
          params.push(logLevel)
        } else {
          params.push("info")
        }
      } else {
        params.push("info")
      }

      return new Promise((resolve, reject) => {
        try {
          startup
            .apply({}, params)
            .then((response: boolean) => {
              if (response) {
                canStart = true
                resolve(true)
              } else {
                if (typeof response === "boolean") {
                  reject("Could not initalize Metlo.")
                } else {
                  reject(response)
                }
              }
            })
            .catch(err => {
              if (typeof err === "string") {
                reject(err)
              } else {
                reject(err & err.message ? err.message : null)
              }
            })
        } catch (err) {
          if (typeof err === "string") {
            reject(err)
          } else {
            reject(err & err.message ? err.message : null)
          }
        }
      })
    }
    return new Promise(() => false)
  } catch (err) {
    enable = false
    Logger().log("debug", err)
    return new Promise(() => false)
  }
}

export const sendMetloTrace = trace => {
  try {
    if (canStart) {
      parse_trace(trace)
    } else {
      if (!silenceNotStartWarnings) {
        Logger().log(
          "debug",
          "Metlo did not start succesfully. Please check logs for more info.",
        )
        silenceNotStartWarnings = true
      }
    }
  } catch (err) {
    Logger().log("debug", err)
  }
}

export const shouldBlock = (requestTrace, requestMetadata) => {
  try {
    if (canStart) {
      return block_trace(requestTrace, requestMetadata)
    } else {
      if (!silenceNotStartWarnings) {
        Logger().log(
          "debug",
          "Metlo did not start succesfully. Please check logs for more info.",
        )
        silenceNotStartWarnings = true
      }
      return false
    }
  } catch (err) {
    Logger().log("debug", err)
    return false
  }
}
